@@ -1,13 +1,12 @@
-#
-# NetPacket::ARP - Decode and endode ARP (Address Resolution Protocol)
-# packets. 
-
 package NetPacket::ARP;
+BEGIN {
+  $NetPacket::ARP::VERSION = '0.43.2';
+}
+# ABSTRACT: Assemble and disassemble ARP (Address Resolution Protocol) packets.
 
 use strict;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
+use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
-our $VERSION = '0.43.0';
 
 BEGIN {
     @ISA = qw(Exporter NetPacket);
@@ -102,14 +101,17 @@ sub encode {
 
 1;
 
-# autoloaded methods go after the END token (&& pod) below
 
-__END__
+
+=pod
 
 =head1 NAME
 
-C<NetPacket::ARP> - Assemble and disassemble ARP (Address Resolution
-Protocol) packets.
+NetPacket::ARP - Assemble and disassemble ARP (Address Resolution Protocol) packets.
+
+=head1 VERSION
+
+version 0.43.2
 
 =head1 SYNOPSIS
 
@@ -274,19 +276,27 @@ Net::PcapUtils::loop(\&process_pkt);
 
 =head1 COPYRIGHT
 
-This is free software; you can redistribute it and/or modify it 
-under the same terms as the Perl 5 programming language system itself.
-
 Copyright (c) 2001 Tim Potter.
 
 Copyright (c) 1995,1996,1997,1998,1999 ANU and CSIRO on behalf of 
 the participants in the CRC for Advanced Computational Systems
 ('ACSys').
 
+This module is free software.  You can redistribute it and/or
+modify it under the terms of the Artistic License 2.0.
+
+This program is distributed in the hope that it will be useful,
+but without any warranty; without even the implied warranty of
+merchantability or fitness for a particular purpose.
+
 =head1 AUTHOR
 
 Tim Potter E<lt>tpot@samba.orgE<gt>
 
 =cut
 
+
+__END__
+
+
 # any real autoloaded methods go after this line
