@@ -1,13 +1,11 @@
-#
-# NetPacket::Ethernet - Decode and encode ethernet packets.
-
 package NetPacket::Ethernet;
 BEGIN {
-  $NetPacket::Ethernet::VERSION = '0.43.1';
+  $NetPacket::Ethernet::VERSION = '0.43.2';
 }
+# ABSTRACT: Assemble and disassemble ethernet packets.
 
 use strict;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
+use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 
 BEGIN {
     @ISA = qw(Exporter NetPacket);
@@ -115,15 +113,17 @@ sub encode {
 
 # autoloaded methods go after the END token (&& pod) below
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
-C<NetPacket::Ethernet> - Assemble and disassemble ethernet packets.
+NetPacket::Ethernet - Assemble and disassemble ethernet packets.
 
 =head1 VERSION
 
-version 0.43.1
+version 0.43.2
 
 =head1 SYNOPSIS
 
@@ -264,15 +264,18 @@ to standard output.
 
 =head1 COPYRIGHT
 
-This is free software; you can redistribute it and/or modify it 
-under the same terms as the Perl 5 programming language system itself.
-
 Copyright (c) 2001 Tim Potter and Stephanie Wehner.
 
 Copyright (c) 1995,1996,1997,1998,1999 ANU and CSIRO on behalf of 
 the participants in the CRC for Advanced Computational Systems
 ('ACSys').
 
+This module is free software.  You can redistribute it and/or
+modify it under the terms of the Artistic License 2.0.
+
+This program is distributed in the hope that it will be useful,
+but without any warranty; without even the implied warranty of
+merchantability or fitness for a particular purpose.
 
 =head1 AUTHOR
 
@@ -280,4 +283,8 @@ Tim Potter E<lt>tpot@samba.orgE<gt>
 
 =cut
 
-# any real autoloaded methods go after this line
\ No newline at end of file
+
+__END__
+
+
+# any real autoloaded methods go after this line
