@@ -4,13 +4,15 @@
 # Encoding part by Stephanie Wehner, atrak@itsx.com
 
 package NetPacket::IP;
+BEGIN {
+  $NetPacket::IP::VERSION = '0.43.2';
+}
+# ABSTRACT: Assemble and disassemble IP (Internet Protocol) packets.
 
 use strict;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
+use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 use NetPacket;
 
-our $VERSION = '0.43.0';
-
 BEGIN {
     @ISA = qw(Exporter NetPacket);
 
@@ -208,12 +210,17 @@ sub encode {
 
 # autoloaded methods go after the END token (&& pod) below
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
-C<NetPacket::IP> - Assemble and disassemble IP (Internet Protocol)
-packets.
+NetPacket::IP - Assemble and disassemble IP (Internet Protocol) packets.
+
+=head1 VERSION
+
+version 0.43.2
 
 =head1 SYNOPSIS
 
@@ -401,15 +408,19 @@ to standard output.
 
 =head1 COPYRIGHT
 
-This is free software; you can redistribute it and/or modify it 
-under the same terms as the Perl 5 programming language system itself.
-
 Copyright (c) 2001 Tim Potter and Stephanie Wehner.
 
 Copyright (c) 1995,1996,1997,1998,1999 ANU and CSIRO on behalf of 
 the participants in the CRC for Advanced Computational Systems
 ('ACSys').
 
+This module is free software.  You can redistribute it and/or
+modify it under the terms of the Artistic License 2.0.
+
+This program is distributed in the hope that it will be useful,
+but without any warranty; without even the implied warranty of
+merchantability or fitness for a particular purpose.
+
 =head1 AUTHOR
 
 Tim Potter E<lt>tpot@samba.orgE<gt>
@@ -418,4 +429,8 @@ Stephanie Wehner E<lt>atrak@itsx.comE<gt>
 
 =cut
 
+
+__END__
+
+
 # any real autoloaded methods go after this line
