@@ -5,9 +5,13 @@
 # Encode and checksumming part, Stephanie Wehner, atrak@itsx.com
 
 package NetPacket::TCP;
+BEGIN {
+  $NetPacket::TCP::VERSION = '0.43.2';
+}
+# ABSTRACT: Assemble and disassemble TCP (Transmission Control Protocol) packets.
 
 use strict;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
+use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 use NetPacket;
 
 my $myclass;
@@ -23,8 +27,6 @@ use constant URG => 0x20;
 use constant ECE => 0x40;
 use constant CWR => 0x80;
 
-our $VERSION = '0.43.0';
-
 BEGIN {
     @ISA = qw(Exporter NetPacket);
 
@@ -184,12 +186,17 @@ sub checksum {
 
 # autoloaded methods go after the END token (&& pod) below
 
-__END__
+
+
+=pod
 
 =head1 NAME
 
-C<NetPacket::TCP> - Assemble and disassemble TCP (Transmission Control
-Protocol) packets.
+NetPacket::TCP - Assemble and disassemble TCP (Transmission Control Protocol) packets.
+
+=head1 VERSION
+
+version 0.43.2
 
 =head1 SYNOPSIS
 
@@ -389,7 +396,6 @@ flag to all TCP packets passing through:
       $divobj->putPacket($packet,$fwtag);
    }
 
-
 =head1 TODO
 
 =over
@@ -404,15 +410,19 @@ flag to all TCP packets passing through:
 
 =head1 COPYRIGHT
 
-This is free software; you can redistribute it and/or modify it 
-under the same terms as the Perl 5 programming language system itself.
-
 Copyright (c) 2001 Tim Potter and Stephanie Wehner.
 
 Copyright (c) 1995,1996,1997,1998,1999 ANU and CSIRO on behalf of 
 the participants in the CRC for Advanced Computational Systems
 ('ACSys').
 
+This module is free software.  You can redistribute it and/or
+modify it under the terms of the Artistic License 2.0.
+
+This program is distributed in the hope that it will be useful,
+but without any warranty; without even the implied warranty of
+merchantability or fitness for a particular purpose.
+
 =head1 AUTHOR
 
 Tim Potter E<lt>tpot@samba.orgE<gt>
@@ -421,4 +431,7 @@ Stephanie Wehner E<lt>atrak@itsx.comE<gt>
 
 =cut
 
-# any real autoloaded methods go after this line
+
+__END__
+
+
